{ config, lib, pkgs, ... }:

{
  # Enable the OpenSSH daemon
  services.openssh.enable = true;
  services.openssh.settings.PermitRootLogin = "no";

  # Activate nix flakes.
  nix.settings.experimental-features = [ "nix-command" "flakes" ];

  time.timeZone = "Europe/Paris";

  i18n.defaultLocale = "en_US.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "fr-bepo";
  };

  environment.systemPackages = with pkgs; [
    emacs
    wget
    htop
    tmux
    bmon # Shows network activity
    nixfmt
    jnettop
    iperf3
    ncdu
    tig
  ];

  programs.git = {
    enable = true;
    config.user = {
      name = "root";
      email = "root@${config.networking.hostName}";
    };
    config.alias = {
      ci = "commit";
      co = "checkout";
      st = "status";
      br = "branch";
    };
  };

  services.emacs = {
    enable = true;
    defaultEditor = true;
  };
}
