# Edit this configuration file to define what should be installed on
# your system. Help is available in the configuration.nix(5) man page, on
# https://search.nixos.org/options and in the NixOS manual (`nixos-help`).

{ config, lib, pkgs, ... }:

let
  vars = import ../vars.nix;
in
{
  imports =
    [
      ./hardware-configuration.nix
      ../common/configuration.nix
    ];

  # Use the GRUB 2 boot loader.
  boot.loader.grub.enable = true;
  boot.loader.grub.device = "/dev/vda";

  networking.hostName = "pastila"; # Define your hostname.
  networking.hostId = "8425e349";

  networking.useDHCP = false;
  networking.interfaces."enp1s0".ipv4.addresses = [ vars.ovenNat.pastila ];
  networking.defaultGateway = {
    address = vars.ovenNat.oven.address;
    interface = "enp1s0";
  };
  networking.nameservers = vars.onlineNetDNS;

  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.armael = {
    isNormalUser = true;
    extraGroups = [ "wheel" ]; # Enable ‘sudo’ for the user.
    openssh.authorizedKeys.keys = [
      "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIBvPrmxY7H6t4ah7d0e7/Jt9RkrPHI1MREukOSSwaqlp armael@teabox"
    ];
  };

  # Open ports in the firewall.
  networking.firewall.allowedTCPPorts =
    map (port: port.num)
      (builtins.filter (port: port.proto == "tcp") vars.ovenNat.forwardPorts);
  networking.firewall.allowedUDPPorts =
    map (port: port.num)
      (builtins.filter (port: port.proto == "udp") vars.ovenNat.forwardPorts);

  # Copy the NixOS configuration file and link it from the resulting system
  # (/run/current-system/configuration.nix). This is useful in case you
  # accidentally delete configuration.nix.
  # system.copySystemConfiguration = true;

  # This option defines the first version of NixOS you have installed on this particular machine,
  # and is used to maintain compatibility with application data (e.g. databases) created on older NixOS versions.
  #
  # Most users should NEVER change this value after the initial install, for any reason,
  # even if you've upgraded your system to a new NixOS release.
  #
  # This value does NOT affect the Nixpkgs version your packages and OS are pulled from,
  # so changing it will NOT upgrade your system.
  #
  # This value being lower than the current NixOS release does NOT mean your system is
  # out of date, out of support, or vulnerable.
  #
  # Do NOT change this value unless you have manually inspected all the changes it would make to your configuration,
  # and migrated your data accordingly.
  #
  # For more information, see `man configuration.nix` or https://nixos.org/manual/nixos/stable/options#opt-system.stateVersion .
  system.stateVersion = "23.11"; # Did you read the comment?

}

